package com.clx.performance.feign;

import com.clx.performance.vo.feign.OrderGoodsFeignVO;
import com.msl.common.result.Result;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.RequestParam;

import javax.validation.constraints.NotBlank;
import javax.validation.constraints.NotNull;
import java.util.List;
import java.util.Set;

@FeignClient(name = "clx-performance")
public interface PerformanceFeign {

    /**
     * 通过货单号获取定向车辆
     *
     * @param orderGoodsNo
     * @return
     */
    @Deprecated
    @GetMapping(value = {"clx-performance/feign/orderGoodsDriverTruck/getTrucksByOrderGoodsNo"})
    Result<List<Integer>> getTrucksByOrderGoodsNo(@RequestParam("orderGoodsNo") @NotBlank(message = "货单编号不可为空") String orderGoodsNo);

    @GetMapping(value = {"clx-performance/feign/orderChild/getOrderChildTotalByUserNo"})
    Integer getOrderChildTotalByUserNo(@RequestParam("userNo") Long userNo);

    @GetMapping(value = {"clx-performance/feign/orderGoods/getOrderGoodsListByOrderNo"})
    List<OrderGoodsFeignVO> getOrderGoodsListByOrderNo(@RequestParam String orderNo);

    /**
     * 公开货源调用
     *
     * @return
     */
    @GetMapping(value = {"clx-performance/feign/orderGoodsDriverTruck/getPublicTruckList"})
    Result<Set<String>> getPublicTruckList();

    /**
     * 定向货源调用
     *
     * @param orderGoodsNo、
     * @param userNo
     * @return
     */
    @GetMapping(value = {"clx-performance/feign/orderGoodsDriverTruck/getPrivateTruckList"})
    Result<List<String>> getPrivateTruckList(@RequestParam("orderGoodsNo") @NotBlank(message = "货单编号不可为空") String orderGoodsNo,
                                             @RequestParam("userNo") @NotNull(message = "用户编号不可为空") Long userNo);

}
